@@ -213,7 +213,7 @@ class AccessTokenMiddleware:
                     header_value = f"{self.config.cookie_name}=null; " \
                                    f"path={path}; " \
                                    f"expires=Thu, 01 Jan 1970 00:00:00 GMT; " \
-                                   f"max-age: 0; " \
+                                   f"max-age=0; " \
                                    f"httponly; " \
                                    f"{'secure; ' if self.config.https_only else ''}" \
                                    f"samesite={self.config.samesite.capitalize()}; " \
